@@ -1,4 +1,8 @@
+#[macro_use]
+extern crate serde;
+
 pub mod structs;
+pub mod traits;
 
 #[cfg(test)]
 mod tests {
