@@ -1,4 +1,5 @@
 pub mod oanda_instrument;
 pub mod oanda_candle_price;
 pub mod oanda_candle;
-pub mod oanda;
+pub mod oanda_trade;
+pub mod oanda_order;
